# streamlit-deeplink
Deep link widget selection values into url query params so that the links are shareable 


# Install
```
pip install streamlit-deeplink

```


# Demo
Widget selections are saved into query params, and we can copy the url with the selection values included for easy sharing.

![example image](https://github.com/karthik17/streamlit-deeplink/raw/main/example_demo.gif)



The below image shows what needed to be changed to convert the example demo to add deeplinks.

![example diff image](https://github.com/karthik17/streamlit-deeplink/raw/main/example_diff.png)



  **Note**

Currently only supports deeplinks for selectbox and multiselect widgets.
